# Oops, I did it again

发生意外错误。要发送错误报告吗？错误报告会自动发送，以防止将来出现类似的问题。

[发送错误消息](opensesame://event.bug_report_send){: .important-button}

隐私:

- 错误消息（见下文）可能包含标识信息，如你的用户名。若这种情况发生，这些信息将不会被用于除修复错误之外的任何其他用途。

信息:

- 操作系统: %(platform)s
- OpenSesame: %(version)s
- Python: %(python_version)s

我不想看到这些消息!

- 如果你不想看到错误报告消息，可以在“菜单→工具→插件和扩展件管理器”下禁用错误报告扩件。这一操作不会禁用错误报告，只会把它们隐藏起来。

错误消息:

%(traceback)s
